Module: Rack

Defined in:
lib/homura/runtime.rb,
lib/homura/runtime/multipart.rb

Overview


  1. Rack::Handler::Homura


Conforms to the Rack handler convention: a module with a ‘run` class method that takes a Rack app, registers it, and arranges for incoming requests to be dispatched through it. See Rack::Handler::Puma, Rack::Handler::WEBrick, etc. for prior art.

Defined Under Namespace

Modules: Handler Classes: Request