Class: Cloudflare::D1Statement

Inherits:
Object
  • Object
show all
Defined in:
lib/homura/runtime.rb

Instance Method Summary collapse

Constructor Details

#initialize(js) ⇒ D1Statement

Returns a new instance of D1Statement.



753
754
755
# File 'lib/homura/runtime.rb', line 753

def initialize(js)
  @js = js
end

Instance Method Details

#allObject

Returns a JS Promise that resolves to a Ruby Array of Ruby Hashes.



765
766
767
768
769
770
# File 'lib/homura/runtime.rb', line 765

def all
  js_stmt = @js
  cf = Cloudflare
  err_cls = Cloudflare::D1Error
  `#{js_stmt}.all().then(function(res) { return #{cf}.$js_rows_to_ruby(res.results); }).catch(function(e) { #{Kernel}.$raise(#{err_cls}.$new(e.message || String(e), Opal.hash({binding_type: 'D1', operation: 'all'}))); })`
end

#bind(*args) ⇒ Object



757
758
759
760
761
762
# File 'lib/homura/runtime.rb', line 757

def bind(*args)
  js_args = `[]`
  args.each { |a| `#{js_args}.push(#{a})` }
  js = @js
  D1Statement.new(`#{js}.bind.apply(#{js}, #{js_args})`)
end

#firstObject

Returns a JS Promise that resolves to a single Ruby Hash (or nil).



773
774
775
776
777
778
# File 'lib/homura/runtime.rb', line 773

def first
  js_stmt = @js
  cf = Cloudflare
  err_cls = Cloudflare::D1Error
  `#{js_stmt}.first().then(function(res) { return res == null ? nil : #{cf}.$js_object_to_hash(res); }).catch(function(e) { #{Kernel}.$raise(#{err_cls}.$new(e.message || String(e), Opal.hash({binding_type: 'D1', operation: 'first'}))); })`
end

#runObject

Returns a JS Promise that resolves to a Ruby Hash with the D1 meta.



781
782
783
784
785
786
# File 'lib/homura/runtime.rb', line 781

def run
  js_stmt = @js
  cf = Cloudflare
  err_cls = Cloudflare::D1Error
  `#{js_stmt}.run().then(function(res) { return #{cf}.$js_object_to_hash(res); }).catch(function(e) { #{Kernel}.$raise(#{err_cls}.$new(e.message || String(e), Opal.hash({binding_type: 'D1', operation: 'run'}))); })`
end