Class: Cloudflare::D1Statement
- Inherits:
-
Object
- Object
- Cloudflare::D1Statement
- Defined in:
- lib/cloudflare_workers.rb
Instance Method Summary collapse
-
#all ⇒ Object
Returns a JS Promise that resolves to a Ruby Array of Ruby Hashes.
- #bind(*args) ⇒ Object
-
#first ⇒ Object
Returns a JS Promise that resolves to a single Ruby Hash (or nil).
-
#initialize(js) ⇒ D1Statement
constructor
A new instance of D1Statement.
-
#run ⇒ Object
Returns a JS Promise that resolves to a Ruby Hash with the D1 meta.
Constructor Details
#initialize(js) ⇒ D1Statement
Returns a new instance of D1Statement.
697 698 699 |
# File 'lib/cloudflare_workers.rb', line 697 def initialize(js) @js = js end |
Instance Method Details
#all ⇒ Object
Returns a JS Promise that resolves to a Ruby Array of Ruby Hashes.
709 710 711 712 713 714 |
# File 'lib/cloudflare_workers.rb', line 709 def all js_stmt = @js cf = Cloudflare err_cls = Cloudflare::D1Error `#{js_stmt}.all().then(function(res) { return #{cf}.$js_rows_to_ruby(res.results); }).catch(function(e) { #{Kernel}.$raise(#{err_cls}.$new(e.message || String(e), Opal.hash({binding_type: 'D1', operation: 'all'}))); })` end |
#bind(*args) ⇒ Object
701 702 703 704 705 706 |
# File 'lib/cloudflare_workers.rb', line 701 def bind(*args) js_args = `[]` args.each { |a| `#{js_args}.push(#{a})` } js = @js D1Statement.new(`#{js}.bind.apply(#{js}, #{js_args})`) end |
#first ⇒ Object
Returns a JS Promise that resolves to a single Ruby Hash (or nil).
717 718 719 720 721 722 |
# File 'lib/cloudflare_workers.rb', line 717 def first js_stmt = @js cf = Cloudflare err_cls = Cloudflare::D1Error `#{js_stmt}.first().then(function(res) { return res == null ? nil : #{cf}.$js_object_to_hash(res); }).catch(function(e) { #{Kernel}.$raise(#{err_cls}.$new(e.message || String(e), Opal.hash({binding_type: 'D1', operation: 'first'}))); })` end |
#run ⇒ Object
Returns a JS Promise that resolves to a Ruby Hash with the D1 meta.
725 726 727 728 729 730 |
# File 'lib/cloudflare_workers.rb', line 725 def run js_stmt = @js cf = Cloudflare err_cls = Cloudflare::D1Error `#{js_stmt}.run().then(function(res) { return #{cf}.$js_object_to_hash(res); }).catch(function(e) { #{Kernel}.$raise(#{err_cls}.$new(e.message || String(e), Opal.hash({binding_type: 'D1', operation: 'run'}))); })` end |